# Release notes for MUSE v1.3.1 (December 19, 2024)

These are the main changes in MUSE v1.3.1.

## Fix errors in the calculation of commodity prices ({github}`552`)

- A number of calculations were incorrect for technologies with output quantities not equal to 1 (as specified in the `CommOut` file), which were effecting the calculation of commodity prices. These have now been fixed.
- See pull requests {github}`601` and {github}`556` for more details
- Issue {github}`551` still remains, but prices should look more reasonable with this release compared to before.
